# Tools

GeoAgent provides LangChain-compatible tools that can be used independently or as part of the agent pipeline.

## STAC Search

::: geoagent.core.tools.stac

## DuckDB Spatial SQL

::: geoagent.core.tools.duckdb_tool

## Raster Analysis

::: geoagent.core.tools.raster

## Vector Operations

::: geoagent.core.tools.vector

## Visualization

::: geoagent.core.tools.viz
